import React from 'react';
import { ContactCard } from './ContactCard';
import { Contact } from '@/types/contact';
import { useContactContext } from '@/contexts/ContactContext';

interface ContactListProps {
  limit?: number;
  onEdit: (id: string) => void;
  onDelete: (id: string) => void;
}

export const ContactList: React.FC<ContactListProps> = ({ 
  limit,
  onEdit,
  onDelete 
}) => {
  const { contacts } = useContactContext();
  
  // Sort contacts by most recently updated
  const sortedContacts = [...contacts].sort(
    (a, b) => new Date(b.updatedAt).getTime() - new Date(a.updatedAt).getTime()
  );

  // Apply limit if provided
  const displayedContacts = limit ? sortedContacts.slice(0, limit) : sortedContacts;

  if (displayedContacts.length === 0) {
    return (
      <div className="text-center py-8">
        <p className="text-muted-foreground">No contacts found.</p>
      </div>
    );
  }

  return (
    <div className="grid gap-4 md:grid-cols-2 lg:grid-cols-3">
      {displayedContacts.map((contact) => (
        <ContactCard
          key={contact.id}
          contact={contact}
          onEdit={onEdit}
          onDelete={onDelete}
        />
      ))}
    </div>
  );
};
