import React from 'react';
import { Card, CardContent, CardHeader, CardTitle } from '@/components/ui/card';
import { useContactContext } from '@/contexts/ContactContext';

export const ContactSummary: React.FC = () => {
  const { contacts } = useContactContext();
  
  // Count contacts by company
  const companyCounts = contacts.reduce<Record<string, number>>((acc, contact) => {
    if (contact.company) {
      acc[contact.company] = (acc[contact.company] || 0) + 1;
    }
    return acc;
  }, {});

  // Get top companies
  const topCompanies = Object.entries(companyCounts)
    .sort((a, b) => b[1] - a[1])
    .slice(0, 3);

  return (
    <Card>
      <CardHeader className="flex flex-row items-center justify-between space-y-0 pb-2">
        <CardTitle className="text-sm font-medium">Contacts</CardTitle>
      </CardHeader>
      <CardContent>
        <div className="text-2xl font-bold">{contacts.length}</div>
        {topCompanies.length > 0 && (
          <div className="mt-2">
            <p className="text-xs text-muted-foreground">Top companies:</p>
            <ul className="text-xs mt-1">
              {topCompanies.map(([company, count]) => (
                <li key={company} className="flex justify-between">
                  <span>{company}</span>
                  <span>{count} contact{count !== 1 ? 's' : ''}</span>
                </li>
              ))}
            </ul>
          </div>
        )}
      </CardContent>
    </Card>
  );
};
