import React from 'react';
import { Card, CardContent, CardFooter, CardHeader, CardTitle } from '@/components/ui/card';
import { Button } from '@/components/ui/button';
import { Badge } from '@/components/ui/badge';
import { Eye, Edit } from 'lucide-react';
import { Project } from '@/types/project';

interface ProjectCardProps {
  project: Project;
  onView: (id: string) => void;
  onEdit: (id: string) => void;
}

export const ProjectCard: React.FC<ProjectCardProps> = ({ project, onView, onEdit }) => {
  const statusColors = {
    'pending': 'bg-yellow-100 text-yellow-800',
    'in-progress': 'bg-blue-100 text-blue-800',
    'completed': 'bg-green-100 text-green-800',
  };

  return (
    <Card className="overflow-hidden">
      <CardHeader className="pb-2">
        <div className="flex justify-between items-start">
          <CardTitle className="text-lg">{project.company}</CardTitle>
          <Badge 
            className={statusColors[project.status as keyof typeof statusColors]}
            variant="outline"
          >
            {project.status}
          </Badge>
        </div>
        <p className="text-sm text-muted-foreground">{project.brand}</p>
      </CardHeader>
      <CardContent className="pb-2">
        <div className="space-y-2">
          <div className="text-sm">
            <span className="font-medium">Due:</span>{' '}
            {new Date(project.dueDate).toLocaleDateString()}
          </div>
          <div className="text-sm">
            <span className="font-medium">Amount:</span>{' '}
            ${project.projectAmount.toLocaleString()}
          </div>
          <div className="text-sm">
            <span className="font-medium">Payment:</span>{' '}
            {project.paymentReceived ? 'Received' : 'Pending'}
          </div>
        </div>
      </CardContent>
      <CardFooter className="pt-2">
        <Button variant="ghost" size="sm" onClick={() => onView(project.id)} className="mr-2">
          <Eye className="h-4 w-4 mr-1" /> View
        </Button>
        <Button variant="ghost" size="sm" onClick={() => onEdit(project.id)}>
          <Edit className="h-4 w-4 mr-1" /> Edit
        </Button>
      </CardFooter>
    </Card>
  );
};
