import React, { useState } from 'react';
import { useProjectContext } from '@/contexts/ProjectContext';
import { ProjectCard } from './ProjectCard';
import { Button } from '@/components/ui/button';
import { Input } from '@/components/ui/input';
import { ProjectForm } from './ProjectForm';
import { Dialog, DialogContent, DialogHeader, DialogTitle, DialogTrigger } from '@/components/ui/dialog';
import { Plus, Search } from 'lucide-react';
import { useNavigate } from 'react-router-dom';

export const ProjectList: React.FC = () => {
  const { projects, addProject } = useProjectContext();
  const [searchTerm, setSearchTerm] = useState('');
  const [isAddDialogOpen, setIsAddDialogOpen] = useState(false);
  const navigate = useNavigate();

  const filteredProjects = projects.filter(project => 
    project.company.toLowerCase().includes(searchTerm.toLowerCase()) ||
    project.brand.toLowerCase().includes(searchTerm.toLowerCase())
  );

  const handleAddProject = (data: any) => {
    const newProject = addProject(data);
    setIsAddDialogOpen(false);
    navigate(`/projects/${newProject.id}`);
  };

  return (
    <div className="space-y-6">
      <div className="flex justify-between items-center">
        <h1 className="text-3xl font-bold tracking-tight">Projects</h1>
        <Dialog open={isAddDialogOpen} onOpenChange={setIsAddDialogOpen}>
          <DialogTrigger asChild>
            <Button>
              <Plus className="mr-2 h-4 w-4" /> Add Project
            </Button>
          </DialogTrigger>
          <DialogContent className="sm:max-w-[600px]">
            <DialogHeader>
              <DialogTitle>Add New Project</DialogTitle>
            </DialogHeader>
            <ProjectForm onSubmit={handleAddProject} />
          </DialogContent>
        </Dialog>
      </div>

      <div className="relative">
        <Search className="absolute left-3 top-3 h-4 w-4 text-muted-foreground" />
        <Input
          placeholder="Search projects..."
          className="pl-10"
          value={searchTerm}
          onChange={(e) => setSearchTerm(e.target.value)}
        />
      </div>

      <div className="grid gap-4 md:grid-cols-2 lg:grid-cols-3">
        {filteredProjects.map(project => (
          <ProjectCard 
            key={project.id} 
            project={project} 
            onView={(id) => navigate(`/projects/${id}`)} 
            onEdit={(id) => navigate(`/projects/${id}/edit`)}
          />
        ))}
        {filteredProjects.length === 0 && (
          <p className="text-muted-foreground col-span-3 text-center py-8">
            {searchTerm ? 'No projects match your search.' : 'No projects yet. Create your first project to get started.'}
          </p>
        )}
      </div>
    </div>
  );
};
