import React from 'react';
import { Link } from 'react-router-dom';
import { cn } from '@/lib/utils';
import { Button } from '@/components/ui/button';
import { Home, FileText, Calendar, Mail, FileBox, FileSpreadsheet, Menu } from 'lucide-react';
import { useAppContext } from '@/contexts/AppContext';
import { useIsMobile } from '@/hooks/use-mobile';

interface SidebarProps {
  className?: string;
}

export const Sidebar: React.FC<SidebarProps> = ({ className }) => {
  const { sidebarOpen, toggleSidebar } = useAppContext();
  const isMobile = useIsMobile();

  const navItems = [
    { name: 'Dashboard', icon: <Home className="h-5 w-5" />, path: '/' },
    { name: 'Projects', icon: <FileText className="h-5 w-5" />, path: '/projects' },
    { name: 'Invoices', icon: <FileSpreadsheet className="h-5 w-5" />, path: '/invoices' },
    { name: 'Calendar', icon: <Calendar className="h-5 w-5" />, path: '/calendar' },
    { name: 'Mail', icon: <Mail className="h-5 w-5" />, path: '/mail' },
    { name: 'Files', icon: <FileBox className="h-5 w-5" />, path: '/files' },
  ];

  return (
    <>
      {isMobile && (
        <Button 
          variant="ghost" 
          size="icon" 
          className="fixed top-4 left-4 z-50" 
          onClick={toggleSidebar}
        >
          <Menu className="h-5 w-5" />
        </Button>
      )}
      <div
        className={cn(
          'fixed inset-y-0 left-0 z-40 flex w-64 flex-col bg-background border-r transition-transform duration-300 ease-in-out',
          isMobile && !sidebarOpen && '-translate-x-full',
          isMobile && sidebarOpen && 'translate-x-0',
          !isMobile && 'translate-x-0',
          className
        )}
      >
        <div className="flex h-16 items-center border-b px-6">
          <h2 className="text-lg font-semibold">UGC Project Tracker</h2>
        </div>
        <nav className="flex-1 overflow-y-auto p-4">
          <ul className="space-y-2">
            {navItems.map((item) => (
              <li key={item.name}>
                <Link
                  to={item.path}
                  className="flex items-center rounded-md px-3 py-2 text-sm font-medium hover:bg-accent hover:text-accent-foreground"
                >
                  {item.icon}
                  <span className="ml-3">{item.name}</span>
                </Link>
              </li>
            ))}
          </ul>
        </nav>
        <div className="border-t p-4">
          <div className="flex items-center">
            <div className="ml-3">
              <p className="text-sm font-medium">UGC Creator</p>
              <p className="text-xs text-muted-foreground">creator@example.com</p>
            </div>
          </div>
        </div>
      </div>
    </>
  );
};
