import React, { createContext, useContext, useState, useEffect, ReactNode } from 'react';
import { supabase } from '@/lib/supabase';
import { Session, User } from '@supabase/supabase-js';

type AuthContextType = {
  session: Session | null;
  user: User | null;
  loading: boolean;
  signIn: (email: string, password: string) => Promise<{ error: any | null }>;
  signUp: (email: string, password: string) => Promise<{ error: any | null, user: User | null }>;
  signOut: () => Promise<void>;
  requestOTP: (phone: string) => Promise<{ error: any | null }>;
  verifyOTP: (phone: string, token: string) => Promise<{ error: any | null }>;
};

export const AuthContext = createContext<AuthContextType | undefined>(undefined);

export const AuthProvider: React.FC<{ children: ReactNode }> = ({ children }) => {
  // Initialize with a mock user since we're removing login functionality
  const mockUser = { id: 'mock-user-id', email: 'user@example.com' } as User;
  
  const [session, setSession] = useState<Session | null>(null);
  const [user, setUser] = useState<User | null>(mockUser);
  const [loading, setLoading] = useState(false); // Set to false to avoid loading state

  // Keep the auth methods but they won't be used in the current implementation
  const signIn = async (email: string, password: string) => {
    return { error: null };
  };

  const signUp = async (email: string, password: string) => {
    return { error: null, user: mockUser };
  };

  const signOut = async () => {
    // No actual sign out needed
  };

  const requestOTP = async (phone: string) => {
    return { error: null };
  };

  const verifyOTP = async (phone: string, token: string) => {
    return { error: null };
  };

  const value = {
    session,
    user,
    loading,
    signIn,
    signUp,
    signOut,
    requestOTP,
    verifyOTP
  };

  return <AuthContext.Provider value={value}>{children}</AuthContext.Provider>;
};

export const useAuth = () => {
  const context = useContext(AuthContext);
  if (context === undefined) {
    throw new Error('useAuth must be used within an AuthProvider');
  }
  return context;
};
