import { AppLayout } from "@/components/AppLayout";
import { Button } from "@/components/ui/button";
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card";
import { Table, TableBody, TableCell, TableHead, TableHeader, TableRow } from "@/components/ui/table";
import { FileIcon, DownloadIcon, TrashIcon } from "lucide-react";
import { FileUploadForm } from "@/components/files/FileUploadForm";

const Files = () => {
  // Mock data for files
  const files = [
    { id: 1, name: "project-brief.pdf", size: "2.4 MB", uploadedAt: "2023-10-15" },
    { id: 2, name: "design-mockup.fig", size: "8.1 MB", uploadedAt: "2023-10-16" },
    { id: 3, name: "requirements.docx", size: "1.2 MB", uploadedAt: "2023-10-17" },
  ];

  const handleUpload = (files: File[]) => {
    console.log('Files to upload:', files);
    // Here you would typically upload the files to your backend
    // and then update the UI with the new files
  };

  const handleDownload = (fileId: number) => {
    console.log('Download file:', fileId);
    // Here you would typically initiate a download for the file
  };

  const handleDelete = (fileId: number) => {
    console.log('Delete file:', fileId);
    // Here you would typically delete the file from your backend
    // and then update the UI
  };

  return (
    <AppLayout>
      <div className="container mx-auto py-6">
        <div className="flex justify-between items-center mb-6">
          <h1 className="text-3xl font-bold">Project Files</h1>
        </div>

        <div className="grid grid-cols-1 md:grid-cols-3 gap-6">
          <div className="md:col-span-2">
            <Card>
              <CardHeader>
                <CardTitle>Files</CardTitle>
                <CardDescription>Manage your project files and documents</CardDescription>
              </CardHeader>
              <CardContent>
                {files.length > 0 ? (
                  <Table>
                    <TableHeader>
                      <TableRow>
                        <TableHead>Name</TableHead>
                        <TableHead>Size</TableHead>
                        <TableHead>Uploaded</TableHead>
                        <TableHead>Actions</TableHead>
                      </TableRow>
                    </TableHeader>
                    <TableBody>
                      {files.map((file) => (
                        <TableRow key={file.id}>
                          <TableCell className="flex items-center">
                            <FileIcon className="mr-2 h-4 w-4" />
                            {file.name}
                          </TableCell>
                          <TableCell>{file.size}</TableCell>
                          <TableCell>{file.uploadedAt}</TableCell>
                          <TableCell>
                            <div className="flex space-x-2">
                              <Button 
                                variant="ghost" 
                                size="sm"
                                onClick={() => handleDownload(file.id)}
                              >
                                <DownloadIcon className="h-4 w-4" />
                              </Button>
                              <Button 
                                variant="ghost" 
                                size="sm" 
                                className="text-red-500"
                                onClick={() => handleDelete(file.id)}
                              >
                                <TrashIcon className="h-4 w-4" />
                              </Button>
                            </div>
                          </TableCell>
                        </TableRow>
                      ))}
                    </TableBody>
                  </Table>
                ) : (
                  <div className="text-center py-6">
                    <p className="text-muted-foreground">No files uploaded yet</p>
                  </div>
                )}
              </CardContent>
            </Card>
          </div>
          
          <div>
            <FileUploadForm onUpload={handleUpload} />
          </div>
        </div>
      </div>
    </AppLayout>
  );
};

export default Files;
