import React from 'react';
import { AppLayout } from '@/components/AppLayout';
import { InvoiceForm } from '@/components/invoices/InvoiceForm';
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from '@/components/ui/card';
import { Button } from '@/components/ui/button';
import { Table, TableBody, TableCell, TableHead, TableHeader, TableRow } from '@/components/ui/table';
import { PlusCircle } from 'lucide-react';

const invoicesData = [
  { id: 1, project: 'Website Redesign', amount: 1500, status: 'Paid', date: '2023-05-15' },
  { id: 2, project: 'Social Media Campaign', amount: 800, status: 'Pending', date: '2023-05-20' },
  { id: 3, project: 'Video Production', amount: 2200, status: 'Overdue', date: '2023-04-30' },
  { id: 4, project: 'SEO Optimization', amount: 950, status: 'Paid', date: '2023-05-10' },
];

const Invoices: React.FC = () => {
  const [showForm, setShowForm] = React.useState(false);

  return (
    <AppLayout>
      <div className="container mx-auto py-6 space-y-6">
        <div className="flex justify-between items-center">
          <h1 className="text-3xl font-bold">Invoices</h1>
          <Button onClick={() => setShowForm(!showForm)}>
            <PlusCircle className="mr-2 h-4 w-4" />
            {showForm ? 'Cancel' : 'New Invoice'}
          </Button>
        </div>

        {showForm && (
          <Card>
            <CardHeader>
              <CardTitle>Create New Invoice</CardTitle>
              <CardDescription>Fill out the form to create a new invoice</CardDescription>
            </CardHeader>
            <CardContent>
              <InvoiceForm onSubmit={() => setShowForm(false)} />
            </CardContent>
          </Card>
        )}

        <Card>
          <CardHeader>
            <CardTitle>Recent Invoices</CardTitle>
            <CardDescription>Manage your invoices and track payments</CardDescription>
          </CardHeader>
          <CardContent>
            <Table>
              <TableHeader>
                <TableRow>
                  <TableHead>Invoice ID</TableHead>
                  <TableHead>Project</TableHead>
                  <TableHead>Amount</TableHead>
                  <TableHead>Status</TableHead>
                  <TableHead>Date</TableHead>
                  <TableHead>Actions</TableHead>
                </TableRow>
              </TableHeader>
              <TableBody>
                {invoicesData.map((invoice) => (
                  <TableRow key={invoice.id}>
                    <TableCell>INV-{invoice.id.toString().padStart(4, '0')}</TableCell>
                    <TableCell>{invoice.project}</TableCell>
                    <TableCell>${invoice.amount}</TableCell>
                    <TableCell>
                      <span
                        className={`px-2 py-1 rounded-full text-xs font-medium ${
                          invoice.status === 'Paid' ? 'bg-green-100 text-green-800' :
                          invoice.status === 'Pending' ? 'bg-yellow-100 text-yellow-800' :
                          'bg-red-100 text-red-800'
                        }`}
                      >
                        {invoice.status}
                      </span>
                    </TableCell>
                    <TableCell>{invoice.date}</TableCell>
                    <TableCell>
                      <Button variant="ghost" size="sm">View</Button>
                      <Button variant="ghost" size="sm">Edit</Button>
                    </TableCell>
                  </TableRow>
                ))}
              </TableBody>
            </Table>
          </CardContent>
        </Card>
      </div>
    </AppLayout>
  );
};

export default Invoices;
