import React from 'react';
import { useNavigate } from 'react-router-dom';
import { Sidebar } from '@/components/ui/sidebar';
import { useProjectContext } from '@/contexts/ProjectContext';
import { Button } from '@/components/ui/button';
import { ArrowLeft } from 'lucide-react';
import { ProjectForm } from '@/components/projects/ProjectForm';

const NewProject: React.FC = () => {
  const { addProject } = useProjectContext();
  const navigate = useNavigate();
  
  const handleSubmit = (data: any) => {
    const newProject = addProject(data);
    navigate(`/projects/${newProject.id}`);
  };

  return (
    <div className="flex min-h-screen bg-background">
      <Sidebar />
      <div className="flex-1 p-8 pt-6 ml-64">
        <Button variant="ghost" onClick={() => navigate('/projects')} className="mb-6">
          <ArrowLeft className="mr-2 h-4 w-4" /> Back to Projects
        </Button>
        
        <h1 className="text-3xl font-bold tracking-tight mb-6">New Project</h1>
        
        <div className="max-w-3xl">
          <ProjectForm onSubmit={handleSubmit} />
        </div>
      </div>
    </div>
  );
};

export default NewProject;
