import React from 'react';
import { useParams, useNavigate } from 'react-router-dom';
import { Sidebar } from '@/components/ui/sidebar';
import { useProjectContext } from '@/contexts/ProjectContext';
import { Button } from '@/components/ui/button';
import { Card, CardContent, CardHeader, CardTitle } from '@/components/ui/card';
import { ArrowLeft, Edit, FileText } from 'lucide-react';

const ProjectDetail: React.FC = () => {
  const { id } = useParams<{ id: string }>();
  const { projects } = useProjectContext();
  const navigate = useNavigate();
  
  const project = projects.find(p => p.id === id);
  
  if (!project) {
    return (
      <div className="flex min-h-screen bg-background">
        <Sidebar />
        <div className="flex-1 p-8 pt-6 ml-64">
          <Button variant="ghost" onClick={() => navigate('/projects')} className="mb-4">
            <ArrowLeft className="mr-2 h-4 w-4" /> Back to Projects
          </Button>
          <div className="text-center py-12">
            <h2 className="text-2xl font-bold">Project not found</h2>
            <p className="text-muted-foreground mt-2">The project you're looking for doesn't exist or has been removed.</p>
          </div>
        </div>
      </div>
    );
  }

  return (
    <div className="flex min-h-screen bg-background">
      <Sidebar />
      <div className="flex-1 p-8 pt-6 ml-64">
        <div className="flex items-center justify-between mb-6">
          <Button variant="ghost" onClick={() => navigate('/projects')} className="mr-4">
            <ArrowLeft className="mr-2 h-4 w-4" /> Back
          </Button>
          <h1 className="text-3xl font-bold tracking-tight flex-1">{project.company} - {project.brand}</h1>
          <Button onClick={() => navigate(`/projects/${id}/edit`)} className="ml-4">
            <Edit className="mr-2 h-4 w-4" /> Edit Project
          </Button>
        </div>

        <div className="grid gap-6 md:grid-cols-2">
          <Card>
            <CardHeader>
              <CardTitle>Project Details</CardTitle>
            </CardHeader>
            <CardContent className="space-y-4">
              <div>
                <h3 className="font-medium">Company</h3>
                <p>{project.company}</p>
              </div>
              <div>
                <h3 className="font-medium">Brand</h3>
                <p>{project.brand}</p>
              </div>
              <div>
                <h3 className="font-medium">Main Contact</h3>
                <p>{project.mainContact}</p>
              </div>
              <div>
                <h3 className="font-medium">Status</h3>
                <p className="capitalize">{project.status}</p>
              </div>
            </CardContent>
          </Card>

          <Card>
            <CardHeader>
              <CardTitle>Financial Details</CardTitle>
            </CardHeader>
            <CardContent className="space-y-4">
              <div>
                <h3 className="font-medium">Project Amount</h3>
                <p>${project.projectAmount.toLocaleString()}</p>
              </div>
              <div>
                <h3 className="font-medium">Payment Status</h3>
                <p>{project.paymentReceived ? 'Received' : 'Pending'}</p>
              </div>
              <div>
                <h3 className="font-medium">Due Date</h3>
                <p>{new Date(project.dueDate).toLocaleDateString()}</p>
              </div>
            </CardContent>
          </Card>

          <Card className="md:col-span-2">
            <CardHeader>
              <CardTitle>Deliverables</CardTitle>
            </CardHeader>
            <CardContent>
              <p>{project.deliverables}</p>
            </CardContent>
          </Card>
        </div>
      </div>
    </div>
  );
};

export default ProjectDetail;
