import React from 'react';
import { useParams, useNavigate } from 'react-router-dom';
import { Sidebar } from '@/components/ui/sidebar';
import { useProjectContext } from '@/contexts/ProjectContext';
import { Button } from '@/components/ui/button';
import { ArrowLeft } from 'lucide-react';
import { ProjectForm } from '@/components/projects/ProjectForm';

const ProjectEdit: React.FC = () => {
  const { id } = useParams<{ id: string }>();
  const { projects, updateProject } = useProjectContext();
  const navigate = useNavigate();
  
  const project = projects.find(p => p.id === id);
  
  if (!project) {
    return (
      <div className="flex min-h-screen bg-background">
        <Sidebar />
        <div className="flex-1 p-8 pt-6 ml-64">
          <Button variant="ghost" onClick={() => navigate('/projects')} className="mb-4">
            <ArrowLeft className="mr-2 h-4 w-4" /> Back to Projects
          </Button>
          <div className="text-center py-12">
            <h2 className="text-2xl font-bold">Project not found</h2>
            <p className="text-muted-foreground mt-2">The project you're looking for doesn't exist or has been removed.</p>
          </div>
        </div>
      </div>
    );
  }

  const handleSubmit = (data: any) => {
    updateProject(id, data);
    navigate(`/projects/${id}`);
  };

  return (
    <div className="flex min-h-screen bg-background">
      <Sidebar />
      <div className="flex-1 p-8 pt-6 ml-64">
        <Button variant="ghost" onClick={() => navigate(`/projects/${id}`)} className="mb-6">
          <ArrowLeft className="mr-2 h-4 w-4" /> Back to Project
        </Button>
        
        <h1 className="text-3xl font-bold tracking-tight mb-6">Edit Project</h1>
        
        <div className="max-w-3xl">
          <ProjectForm 
            onSubmit={handleSubmit} 
            initialData={project} 
          />
        </div>
      </div>
    </div>
  );
};

export default ProjectEdit;
